#### General

Node ID
  {$ ctrl.node.uuid $}
Chassis ID
  {$ ctrl.node.chassis_uuid | noValue $}
Created At
  {$ ctrl.node.created_at | date:'medium' $}
Extra
  {$ ctrl.node.extra $}

#### Ports

{$ 'Create port' | translate $} {$ 'Delete ports' | translate $}
| MAC Address | Extra | Actions
--- | --- | --- | ---
| {$ port.address $} | {$ port.address $} | {$ id $} {$ value $} |

#### Properties

{$ propertyName $}
  {$ propertyValue $}

#### Driver Info

Driver
  {$ ctrl.node.driver $}
SSH Port
  {$ ctrl.node.driver_info.ssh_port $}
SSH Username
  {$ ctrl.node.driver_info.ssh_username $}
Deploy Kernel
  {$ ctrl.node.driver_info.deploy_kernel $} {$ ctrl.node.driver_info.deploy_kernel $}
Deploy Ramdisk
  {$ ctrl.node.driver_info.deploy_ramdisk $} {$ ctrl.node.driver_info.deploy_ramdisk $}

{$ id $}
  {$ value $}

#### Capabilities

  {$ ctrl.node.capabilities $}

#### Instance Info

Instance Name
  {$ ctrl.node.instance_info.display_name $}
Ramdisk
  {$ ctrl.node.instance_info.ramdisk $}
Kernel
  {$ ctrl.node.instance_info.kernel $}

{$ id $}
  {$ value $}